@@ -28,7 +28,7 @@ odb.comments = function(
 	validObject(odb)
 	
 	# Text reading
-	content <- scan(file=sprintf("%s/content.xml", odb@directory), what="", sep="\n", quiet=TRUE, fileEncoding="UTF8")
+	content <- scan(file=sprintf("%s/content.xml", odb@directory), what="", sep="\n", quiet=TRUE, fileEncoding="UTF-8")
 	content <- paste(content, collapse="\n")
 	
 	# Target positions
