@@ -39,7 +39,7 @@
 	value = rep(value, length.out=maxLength)
 	
 	# Text reading
-	content <- scan(file=sprintf("%s/content.xml", odb@directory), what="", sep="\n", quiet=TRUE, fileEncoding="UTF8")
+	content <- scan(file=sprintf("%s/content.xml", odb@directory), what="", sep="\n", quiet=TRUE, fileEncoding="UTF-8")
 	content <- paste(content, collapse="\n")
 	
 	# Create tables section
@@ -106,7 +106,7 @@
 	}
 	
 	# Save XML to file
-	conn <- file(sprintf("%s/content.xml", odb@directory), open="wt", blocking=FALSE, encoding="UTF8")
+	conn <- file(sprintf("%s/content.xml", odb@directory), open="wt", blocking=FALSE, encoding="UTF-8")
 	cat(content, file=conn)
 	close(conn)
 	
